@@ -1,7 +1,7 @@
 data("raman_hdpe")
 
 # Create temp dir for testthat
-tmp <- file.path(tempdir(), "testthat")
+tmp <- file.path(tempdir(), "OpenSpecy-testthat")
 dir.create(tmp, showWarnings = F)
 
 test_that("share_text() gives expected output", {
